==> ksnuffle-0.1.tgz: ksnuffle-0.1/ksnuffle/knd_setup.moc.cpp <==
/****************************************************************************
** KNDSetup meta object code from reading C++ file 'knd_setup.h'
**
** Created: Fri May 28 21:51:51 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "knd_setup.h"
#include <qmetaobject.h>


const char *KNDSetup::className() const
{
    return "KNDSetup";
}

QMetaObject *KNDSetup::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KNDSetup(&KNDSetup::staticMetaObject);

#endif

void KNDSetup::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("KNDSetup","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KNDSetup::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    typedef void(KNDSetup::*m1_t0)();
    typedef void(KNDSetup::*m1_t1)();
    typedef void(KNDSetup::*m1_t2)();
    typedef void(KNDSetup::*m1_t3)();
    typedef void(KNDSetup::*m1_t4)();
    typedef void(KNDSetup::*m1_t5)();
    m1_t0 v1_0 = &KNDSetup::clickSaveSetup;
    m1_t1 v1_1 = &KNDSetup::clickAddUser;
    m1_t2 v1_2 = &KNDSetup::clickRemUser;
    m1_t3 v1_3 = &KNDSetup::clickRemAll;
    m1_t4 v1_4 = &KNDSetup::clickSaveUsers;
    m1_t5 v1_5 = &KNDSetup::clickSetUID;
    QMetaData *slot_tbl = new QMetaData[6];
    slot_tbl[0].name = "clickSaveSetup()";
    slot_tbl[1].name = "clickAddUser()";
    slot_tbl[2].name = "clickRemUser()";
    slot_tbl[3].name = "clickRemAll()";
    slot_tbl[4].name = "clickSaveUsers()";
    slot_tbl[5].name = "clickSetUID()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    metaObj = new QMetaObject( "KNDSetup", "QWidget",
	slot_tbl, 6,
	0, 0 );
}

==> ksnuffle-0.6.tgz: ksnuffle-0.6/ksnuffle/knd_setup.moc.cpp <==
/****************************************************************************
** KNDSetup meta object code from reading C++ file 'knd_setup.h'
**
** Created: Wed Apr 5 15:07:12 2000
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "knd_setup.h"
#include <qmetaobject.h>


const char *KNDSetup::className() const
{
    return "KNDSetup";
}

QMetaObject *KNDSetup::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KNDSetup(&KNDSetup::staticMetaObject);

#endif

void KNDSetup::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("KNDSetup","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KNDSetup::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    typedef void(KNDSetup::*m1_t0)();
    typedef void(KNDSetup::*m1_t1)();
    m1_t0 v1_0 = &KNDSetup::clickSaveSetup;
    m1_t1 v1_1 = &KNDSetup::clickPickFont;
    QMetaData *slot_tbl = new QMetaData[2];
    slot_tbl[0].name = "clickSaveSetup()";
    slot_tbl[1].name = "clickPickFont()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    metaObj = new QMetaObject( "KNDSetup", "QWidget",
	slot_tbl, 2,
	0, 0 );
}
